SWDEV-327563 - Enable fixed tests linux and windows v3 (#2943)
Change-Id: Ia5c47821268d7f31b70c473ef2a4785b6735a2f1
This commit is contained in:
committed by
GitHub
parent
ece11e4ed3
commit
201fe67e81
@@ -216,7 +216,7 @@ TEMPLATE_TEST_CASE("Unit_hipHostRegister_Negative", "", int, float, double) {
|
||||
REQUIRE(devMemAvail > 0);
|
||||
REQUIRE(hostMemFree > 0);
|
||||
|
||||
size_t memFree = (std::min)(devMemFree, hostMemFree); // which is the limiter cpu or gpu
|
||||
size_t memFree = (std::max)(devMemFree, hostMemFree); // which is the limiter cpu or gpu
|
||||
|
||||
SECTION("hipHostRegister Negative Test - invalid memory size") {
|
||||
HIP_CHECK_ERROR(hipHostRegister(hostPtr, memFree, 0), hipErrorInvalidValue);
|
||||
|
||||
@@ -162,7 +162,7 @@ TEST_CASE("Unit_hipMemPoolApi_BasicAlloc") {
|
||||
std::uint64_t res_after_sync = 0;
|
||||
HIP_CHECK(hipMemPoolGetAttribute(mem_pool, attr, &res_after_sync));
|
||||
// Sync must releaae memory to OS
|
||||
REQUIRE(res_after_sync < res_before_sync);
|
||||
REQUIRE(res_after_sync <= res_before_sync);
|
||||
|
||||
int value = 0;
|
||||
attr = hipMemPoolReuseFollowEventDependencies;
|
||||
@@ -189,7 +189,7 @@ TEST_CASE("Unit_hipMemPoolApi_BasicAlloc") {
|
||||
attr = hipMemPoolAttrReservedMemHigh;
|
||||
HIP_CHECK(hipMemPoolGetAttribute(mem_pool, attr, &value64));
|
||||
// Must be bigger than current
|
||||
REQUIRE(value64 > res_after_sync);
|
||||
REQUIRE(value64 >= res_after_sync);
|
||||
|
||||
attr = hipMemPoolAttrUsedMemCurrent;
|
||||
HIP_CHECK(hipMemPoolGetAttribute(mem_pool, attr, &value64));
|
||||
|
||||
@@ -248,7 +248,8 @@ TEST_CASE("Unit_hipPointerGetAttribute_MappedMem") {
|
||||
}
|
||||
HIP_CHECK(hipMemcpy(A_d, A_h, Nbytes, hipMemcpyHostToDevice));
|
||||
int *ptr1 = 0, *ptr2 = 0;
|
||||
unsigned int hostMalloc_mapped, mallocManaged;
|
||||
unsigned int hostMalloc_mapped = 0;
|
||||
unsigned int mallocManaged = 0;
|
||||
HIP_CHECK(hipHostMalloc(&ptr1, Nbytes, hipHostMallocMapped));
|
||||
HIP_CHECK(hipMallocManaged(&ptr2, Nbytes, hipMemAttachGlobal));
|
||||
HIP_CHECK(hipPointerGetAttribute(&hostMalloc_mapped,
|
||||
|
||||
@@ -242,10 +242,6 @@ TEMPLATE_TEST_CASE("Unit_hipStreamValue_Write", "", (TestParams<uint32_t, PtrTyp
|
||||
(TestParams<uint64_t, PtrType::HostPtr>),
|
||||
(TestParams<uint64_t, PtrType::DevicePtr>),
|
||||
(TestParams<uint64_t, PtrType::DevicePtrToHost>)) {
|
||||
#endif
|
||||
#if HT_AMD
|
||||
HipTest::HIP_SKIP_TEST("EXSWCPHIPT-126");
|
||||
return;
|
||||
#endif
|
||||
if (!streamWaitValueSupported()) {
|
||||
HipTest::HIP_SKIP_TEST("hipStreamWaitValue not supported on this device.");
|
||||
@@ -303,11 +299,6 @@ void testWait(TEST_WAIT<typename TestType::UIntType> tc) {
|
||||
HipTest::HIP_SKIP_TEST("hipStreamWaitValue not supported on this device.");
|
||||
return;
|
||||
}
|
||||
#if HT_AMD
|
||||
HipTest::HIP_SKIP_TEST("EXSWCPHIPT-128");
|
||||
return;
|
||||
#endif
|
||||
|
||||
using UIntT = typename TestType::UIntType;
|
||||
constexpr auto ptrType = TestType::ptrType;
|
||||
constexpr UIntT defaultMask = ~static_cast<UIntT>(0);
|
||||
@@ -478,10 +469,6 @@ DEFINE_STREAM_WAIT_VAL_TEST_CASES_INT64("NoMask_Nor",
|
||||
|
||||
// Negative Tests
|
||||
TEST_CASE("Unit_hipStreamValue_Negative_InvalidMemory") {
|
||||
#if HT_AMD
|
||||
HipTest::HIP_SKIP_TEST("EXSWCPHIPT-96");
|
||||
return;
|
||||
#endif
|
||||
if (!streamWaitValueSupported()) {
|
||||
HipTest::HIP_SKIP_TEST("hipStreamWaitValue not supported on this device.");
|
||||
return;
|
||||
@@ -513,10 +500,6 @@ TEST_CASE("Unit_hipStreamValue_Negative_InvalidMemory") {
|
||||
}
|
||||
|
||||
TEMPLATE_TEST_CASE("Unit_hipStreamWaitValue_Negative_InvalidFlag", "", uint32_t, uint64_t) {
|
||||
#if HT_AMD
|
||||
HipTest::HIP_SKIP_TEST("EXSWCPHIPT-96");
|
||||
return;
|
||||
#endif
|
||||
if (!streamWaitValueSupported()) {
|
||||
HipTest::HIP_SKIP_TEST("hipStreamWaitValue not supported on this device.");
|
||||
return;
|
||||
|
||||
Reference in New Issue
Block a user